#
# spec file for package libuv
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define somajor 1
Name:           libuv
Version:        1.48.0
Release:        1.3
Summary:        Asychronous I/O support library
License:        MIT
URL:            https://libuv.org
Source0:        https://dist.libuv.org/dist/v%{version}/libuv-v%{version}.tar.gz
Source1:        https://dist.libuv.org/dist/v%{version}/libuv-v%{version}.tar.gz.sign
# https://github.com/libuv/libuv/blob/v1.x/MAINTAINERS.md
Source2:        %{name}.keyring
Source3:        baselibs.conf
Patch1:         fix_tests.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkgconfig

%description
libuv is a support library with a focus on asynchronous I/O. It was
primarily developed for use by Node.js, but it is also used by
Mozilla's Rust language, Luvit, Julia, pyuv, and others.

%package     -n libuv%{somajor}
Summary:        Asychronous I/O support library

%description -n libuv%{somajor}
libuv is a support library with a focus on asynchronous I/O. It was
primarily developed for use by Node.js, but it is also used by
Mozilla's Rust language, Luvit, Julia, pyuv, and others.

%package        devel
Summary:        Development libraries for libuv
BuildRequires:  glibc-devel
Requires:       libuv%{somajor} = %{version}

%description    devel
Development files for libuv.

libuv is a support library with a focus on asynchronous I/O. It was
primarily developed for use by Node.js, but it is also used by
Mozilla's Rust language, Luvit, Julia, pyuv, and others.

%prep
%autosetup -p1 -n %{name}-v%{version}

%build
./autogen.sh
%configure \
  --disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%check
%if !0%{?qemu_user_space_build}
%make_build check
%endif

%post -n libuv%{somajor} -p /sbin/ldconfig
%postun -n libuv%{somajor} -p /sbin/ldconfig

%files -n libuv%{somajor}
%license LICENSE
%{_libdir}/libuv.so.%{somajor}*

%files devel
%doc AUTHORS CONTRIBUTING.md ChangeLog README.md
%license LICENSE
%{_libdir}/libuv.so
%{_includedir}/uv*
%{_libdir}/pkgconfig/libuv.pc

%changelog
* Thu Mar 14 2024 jun wang <jgwang@suse.com>
- Update to version 1..48.0
  * CVE-2024-24806: Improper Domain Lookup that potentially leads
    to SSRF attacks (bsc#1219724)
  * misc: remove deprecated stalebot file
  * misc: ignore libuv-release-tool files
  * build,win: remove extraneous -lshell32
  * build,win: work around missing uuid.dll on MinGW
  * build: disable windows asan buildbot
  * build: add .cache clangd folder to .gitignore
  * build: re-enable msvc-asan job on CI
  * linux: disable io_uring on hppa below kernel 6.1.51
  * linux: remove HAVE_IFADDRS_H macro
  * linux: fix bind/connect for abstract sockets
  * linux: retry fs op if unsupported by io_uring
  * linux: disable io_uring on ppc64 and ppc64le
  * unix,win: utility for setting priority for thread
  * unix,win: fix read past end of pipe name buffer
  * unix,win: fix busy loop with zero timeout timers
  * unix,win: reset the timer queue on stop
  * unix: ignore ifaddrs with NULL ifa_addr
  * unix: unbreak macOS < 10.14
  * unix: correct pwritev conditional
  * unix: support full TCP keep-alive on Solaris
  * unix: optimize uv__tcp_keepalive cpp directives
  * freebsd: fix F_KINFO file path handling
  * freebsd: fix build on non-intel archs
  * aix: disable ipv6 link local
  * aix,ibmi: use uv_interface_addresses instead of getifaddrs
  * win: remove check for UV_PIPE_NO_TRUNCATE
  * win: honor NoDefaultCurrentDirectoryInExePath env var
  * win: stop using deprecated names
  * win: replace c99 comments with c89 comments
  * win: fix ESRCH implementation
  * win/spawn: optionally run executable paths with no file
    extension
  * test: don't run tcp_writealot under msan
  * test: check if ipv6 link-local traffic is routable
  * test: skip tcp-write-in-a-row on IBM i
  * test: empty strings are not valid IDNA
  * test_fs.c: Fix issue on 32-bit systems using btrfs
  * idna: fix compilation warning
  * pipe: add back error handling to connect / bind
  * fix: always zero-terminate idna output
  * fix: reject zero-length idna inputs
  * doc: move cjihrig to emeriti
  * doc: add very basic Security Policy document
  * Merge pull request from GHSA-f74f-cvh7-c6q6
- Remove ppc64-disable-liburing.patch because it was applied
  in the current source code
* Mon Jan 15 2024 Dirk Müller <dmueller@suse.com>
- add ppc64-disable-liburing.patch (bsc#1218365)
* Wed Nov 15 2023 Marcus Meissner <meissner@suse.com>
- libuv.keyring: added keyid 79A67C55A3679C8B
  Jameson Nash <vtjnash@gmail.com>
* Wed Nov  8 2023 Ondřej Súkup <mimi.vx@gmail.com>
- refresh fix_tests.patch
- Update to 1.47.0
  * test: fix license blurb (Ben Noordhuis)
  * linux: fix harmless warn_unused_result warning (Shuduo Sang)
  * darwin: fix build warnings (小明)
  * linux: don't use io_uring on pre-5.10.186 kernels (Ben Noordhuis)
  * fs: fix WTF-8 decoding issue (Jameson Nash)
  * test: enable disabled tcp_connect6_error_fault Ben Noordhuis)(
  * test: enable disabled fs_link (Ben Noordhuis)
  * test: enable disabled spawn_same_stdout_stderr (Ben Noordhuis)
  * linux: handle UNAME26 personality (Ben Noordhuis)
  * build: move cmake_minimum_required version to 3.9 (Keith Winstein)
  * unix: set ipv6 scope id for link-local addresses (Ben Noordhuis)
  * unix: match kqueue and epoll code (Trevor Norris)
  * win,spawn: allow `%%PATH%%` to be unset (Kyle Edwards)
  * doc: switch to Furo, a more modern Sphinx theme (Saúl Ibarra Corretgé)
  * darwin: make TCP_KEEPINTVL and TCP_KEEPCNT available (小明)
  * win,fs: avoid winapi macro redefinition (Brad King)
  * linux: add missing riscv syscall numbers (michalbiesek)
  * doc: fix broken "Shared library" Wikipedia link (Alois Klink)
  * unix: get mainline kernel version in Ubuntu (Santiago Gimeno)
  * unix: get mainline kernel version in Debian (Ben Noordhuis)
  * unix: disable io_uring close on selected kernels (Santiago Gimeno)
  * test: skip tests when ipv6 is not available (Santiago Gimeno)
  * ibmi: implement ifaddrs, getifaddrs, freeifaddrs (Abdirahim Musse)
  * unix: reset signal counters after fork (SmorkalovG)
  * unix: remove pread/preadv conditionals (Ben Noordhuis)
  * unix: remove pwrite/pwritev conditionals (Ben Noordhuis)
  * darwin: remove workaround for data corruption bug (Ben Noordhuis)
  * src: default to stream=stderr in handle printer (Ben Noordhuis)
  * test: switch to new-style ASSERT_EQ macros (Pleuvens)
  * zos: correctly get cpu model in uv_cpu_info() (jolai)
  * test: fix get_passwd2 on IBM i (Abdirahim Musse)
  * unix: don't malloc on sync uv_fs_read (Ben Noordhuis)
  * freebsd: get fs event path with fcntl(F_KINFO) (David Carlier)
  * test: switch from ASSERT_* to ASSERT_PTR_* (Pleuvens)
  * darwin: workaround apple pthread_cond_wait bug (Julien Roncaglia)
  * doc: uv_close should be called after exit callback (Pleuvens)
  * test: 192.0.2.0/24 is the actual -TEST-NET-1 (prubel)
  * unix: add back preadv/pwritev fallback (Ben Noordhuis)
  * unix: rename variable for consistency (Ben Noordhuis)
  * unix: merge read/write code into single functions (Ben Noordhuis)
  * doc: filename arg to uv_fs_event_cb can be NULL (Ben Noordhuis)
  * build,win: we need to link against shell32.lib (Per Allansson)
  * unix: no preadv/pwritev workaround if not needed (Jeffrey H. Johnson)
  * build: add CI for Windows ARM64 (build only) (Per Allansson)
  * linux: disable io_uring on 32 bits arm systems (Ben Noordhuis)
  * misc: export WTF8 conversion utilities (Jameson Nash)
  * build: fix libuv.a file name for cmake (Jameson Nash)
  * build: add windows ubsan and clang ci (Matheus Izvekov)
  * win: improve accuracy of ProductName between arch (Christian Heimlich))
* Thu Jul 20 2023 Joshua Smith <jsmithfpv@gmail.com>
- Switched keyring from Jameson Nash (vtjnash) to Santiago Gimeno
  (santigimeno)
- Update to 1.46.0:
  * Add some more iouring backend fs ops
  * work around io_uring IORING_OP_CLOSE bug
- Updates in version 1.45.0:
  * introduce io_uring support
  * give thread pool threads an 8 MB stack
  * change execution order of timers
* Fri Sep 23 2022 Dirk Müller <dmueller@suse.com>
- skip testsuite on qemu_user_mode emulated builds, no chance
  of ever succeeding
* Mon Jul 18 2022 Dirk Müller <dmueller@suse.com>
- update to 1.44.2:
  * Add SHA to ChangeLog
  * aix, ibmi: handle server hang when remote sends TCP RST
  * process: reset the signal mask if the fork fails
  * zos: implement cmpxchgi() using assembly
  * ibmi: Implement UDP disconnect
  * unix: simplify getpwuid call
  * process,iOS: fix build breakage in process.c
  * test: remove unused declarations in tcp_rst test
  * core: add thread-safe strtok implementation
  * test: fix flaky file watcher test
  * unix,win: fix UV_RUN_ONCE + uv_idle_stop loop hang
  * win: fix unexpected ECONNRESET error on TCP socket
  * doc: make sample cross-platform build
  * test: separate some static variables by test cases
  * sunos: fs-event callback can be called after uv_close()
  * uv: re-register interest in a file after change
  * uv: register UV_RENAME event for _RFIM_UNLINK
  * uv: register __rfim_event 156 as UV_RENAME
  * release: check versions of autogen scripts are newer
  * test: rewrite embed test
  * unix: use MSG_CMSG_CLOEXEC where supported
  * test: remove disabled callback_order test
  * kqueue: skip EVFILT_PROC when invalidating fds
  * zos: don't err when killing a zombie process
  * zos: avoid fs event callbacks after uv_close()
  * zos: correctly format interface addresses names
  * zos: add uv_interface_addresses() netmask support
  * zos: improve memory management of ip addresses
  * tcp,pipe: fail `bind` or `listen` after `close`
  * zos: implement uv_available_parallelism()
  * udp,win: fix UDP compiler warning
  * zos: fix early exit of epoll_wait()
  * unix,tcp: fix errno handling in uv__tcp_bind()
  * shutdown,unix: reduce code duplication
  * unix: fix c99 comments
  * unix: retry tcgetattr/tcsetattr() on EINTR
  * unix,stream: optimize uv_shutdown() codepath
  * unix,tcp: allow EINVAL errno from setsockopt in uv_tcp_close_reset()
  * win,shutdown: improve how shutdown is dispatched
* Sun Mar 13 2022 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.44.1:
  * fix a hang after NOTE_EXIT
- inclues changes from 1.44.0:
  * Support for poxix_spawn API
  * updates to documentation, tests, benchmarks and build scripts
* Sat Feb 12 2022 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.43.0:
  * protect fork in uv_spawn from signals
  * drop only successfully sent packets post sendmmsg
  * adjust stalebot deadline
  * work around CIFS EPERM bug
  * documentation fixes
  * developer visible code fixes
* Sun Sep 12 2021 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.42.0:
  * more errno mappings and fixes
  * higher performance try-writes
  * fix string encoding issue of uv_os_gethostname
  * Workarounds for a copy_file_range kernel bug
  * Better support for TSan
* Tue Jul 13 2021 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.41.1:
  * CVE-2021-22918: fix out of bounds read in punycode decoder
    (bsc#1187973)
* Tue Feb 23 2021 Dirk Müller <dmueller@suse.com>
- update to 1.41.0:
  * mailmap: update contact information for richardlau
  * build: add asan checks
  * unix: report bind error in uv_tcp_connect
  * doc: uv_tcp_bind
  * test: fix pump and tcp_write_batch benchmarks
  * doc: mark IBM i as Tier 2 support
  * doc,poll: add notes
  * linux: fix -Wincompatible-pointer-types warning
  * linux: fix -Wsign-compare warning
  * unix,win: harmonize uv_read_start
  * unix,win: more uv_read_start
  * build: turn on -fno-strict-aliasing
  * stream: add uv_pipe and uv_socketpair to the API
  * unix,win: initialize timer `timeout` field
  * bsd-ifaddrs: improve comments
  * test: remove unnecessary uv_fs_stat
  * fs: fix utime/futime timestamp rounding errors
  * test: ensure reliable floating point comparison
  * unix,fs: fix uv_fs_sendfile
  * unix: fix uv_fs_stat when using statx
  * linux,macos: fix uv_set_process_title regression
  * doc: clarify UDP errors and recvmmsg
  * test-getaddrinfo: use example.invalid
  * Revert "build: fix android autotools build"
  * unix,fs: on DVS fs, statx returns EOPNOTSUPP
  * win, fs: mkdir really return UV_EINVAL for invalid names
  * tools: migrate tools/make_dist_html.py to python3
  * unix: fix uv_uptime
  * unix: check for partial copy_file_range support
  * win: bump minimum supported version to windows 8
  * poll,unix: ensure safety of rapid fd reuse
  * test: fix some warnings
  * unix: fix uv_uptime
  * doc: fix versionadded metadata
  * test: fix 'incompatible pointer types' warnings
  * unix: check for EXDEV in uv__fs_sendfile
* Wed Nov 25 2020 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.40.0:
  * udp: add UV_UDP_MMSG_FREE recv_cb flag
  * include: re-map UV__EPROTO from 4046 to -4046
  * doc: correct UV_UDP_MMSG_FREE version added
  * doc: add uv_metrics_idle_time() version metadata
  * src: suppress user_timeout maybe-uninitialized
  * test: fix compiler warning
  * build: fix the Haiku cmake build
  * linux: fix i386 sendmmsg/recvmmsg support
  * build: add libuv-static pkg-config file
  * build,unix: add QNX support
  * include: remove incorrect UV__ERR() for EPROTO
* Sat Sep 12 2020 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.39.0:
  * unix: use relaxed loads/stores for clock id
  * unix: squelch harmless valgrind warning
  * linux: use copy_file_range for uv_fs_copyfile when possible
  * udp: add uv_udp_using_recvmmsg query
  * include: add internal fields struct to uv_loop_t
  * core: add API to measure event loop idle time
  * unix: handle src, dest same in uv_fs_copyfile()
  * unix: error when uv_setup_args() is not called
  * fs: clobber req->path on uv_fs_mkstemp() error
  * tcp: fail instantly if local port is unbound
  * unix: don't use _POSIX_PATH_MAX
  * build system fixes, documentation updates, updates to tests
* Sat Aug 15 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.38.1
  * test: use last matching qemu version (cjihrig)
  * win, util: rearrange uv_hrtime (Bartosz Sosnowski)
  * test: skip signal_multiple_loops test on QEMU (gengjiawen)
  * build: add android build to CI (gengjiawen)
  * test: extend fs_event_error_reporting timeout (cjihrig)
  * build: link libkvm on netbsd only (Alexander Tokmakov)
  * linux: refactor /proc file reader logic (Ben Noordhuis)
  * linux: read load average from /proc/loadavg (Ben Noordhuis)
  * android: remove patch code for below 21 (gengjiawen)
  * win: fix visual studio 2008 build (Arenoros)
  * win,tty: fix deadlock caused by inconsistent state (lander0s)
  * unix: use relaxed loads/stores for feature checks (Ben Noordhuis)
  * build: don't .gitignore m4/ax_pthread.m4 (Ben Noordhuis)
  * unix: fix gcc atomics feature check (Ben Noordhuis)
  * darwin: work around clock jumping back in time (Ben Noordhuis)
  * udp: fix write_queue cleanup on sendmmsg error (Santiago Gimeno)
  * src: build fix for Android (David Carlier)
  * win: remove dep on GetQueuedCompletionStatusEx (Colin Finck)
  * doc: correct source lines (Shohei YOSHIDA)
  * build,android: fix typo (twosee)
  * doc: uv_cancel() handles uv_random_t requests (Philip Chimento)
  * doc: fix unescaped character (Philip Chimento)
  * build,cmake: fix compilation on old MinGW (erw7)
  * build: remove unnessesary MSVC warnings (Bartosz Sosnowski)
  * win: make uv_udp_init_ex() accept UV_UDP_RECVMMSG (Ben Noordhuis)
  * unix: simplify uv__udp_init_ex() (Ben Noordhuis)
  * win: remove MAX_PATH limitations (Bartosz Sosnowski)
  * build, win: add long path aware manifest (Bartosz Sosnowski)
  * doc: check/idle/prepare functions always succeed (Ben Noordhuis)
  * darwin: fix build with non-apple compilers (Ben Noordhuis)
  * win: support environment variables > 32767 chars (Ben Noordhuis)
  * unix: fully initialize struct msghdr (Ben Noordhuis)
  * doc: add uv_replace_allocator thread safety warning (twosee)
  * unix: fix int overflow when copying large files (Michal Artazov)
  * fs: report original error (Bartosz Sosnowski)
  * win, fs: add IO_REPARSE_TAG_APPEXECLINK support (Bartosz Sosnowski)
  * doc: fix formatting (Ben Noordhuis)
  * unix: fix memory leak when uv_loop_init() fails (Anna Henningsen)
  * unix: shrink uv_udp_set_source_membership() stack (Ben Noordhuis)
  * unix,win: fix wrong sizeof argument to memcpy() (Ben Noordhuis)
  * build: check for libraries not provided by libc (Jeroen Roovers)
  * doc: fix the order of arguments to calloc() (MasterDuke17)
  * unix: don't abort when getrlimit() fails (Ben Noordhuis)
  * test: support common user profile on IBMi (Xu Meng)
  * build: test on more platforms via QEMU in CI (gengjiawen)
  * build: add aix-common.c for AIX cmake build (Jesse Gorzinski)
  * zos: explicitly mark message queue events (Irek Fakhrutdinov)
  * zos: move mq check out of loop to save cpu cycles (Irek Fakhrutdinov)
  * zos: add checks to ensure behavior of epoll_wait (Irek Fakhrutdinov)
  * src: add uv__reallocf() (Ben Noordhuis)
  * build: ibmi support for cmake (Jesse Gorzinski)
  * build: fix gyp build for Android API >= 28 (Lin Zhang)
  * udp: return recvmmsg-ed datagrams in order (Saúl Ibarra Corretgé)
  * zos,test: fix spawn_empty_env for shared library build (Richard Lau)
  * zos: fix non-Release builds (Richard Lau)
  * zos: fix return value on expired nanosleep() call (Richard Lau)
  * build: fix z/OS cmake build (Richard Lau)
  * test: add a bunch of ASSERT macros (Santiago Gimeno)
  * test: remove unused extern declaration (Ben Noordhuis)
  * test: canonicalize argv[0] in exepath test (Ben Noordhuis)
  * test: simplify platform_init() (Ben Noordhuis)
  * ibmi: Fix isatty EBADF handling and refactor (Kevin Adler)
  * test: Test EBADF tty handling (Kevin Adler)
  * build: make cmake build benchmarks (Ben Noordhuis)
  * win: use RtlGenRandom from advapi32.dll directly (Ben Noordhuis)
  * android: fix OOB write in uv_interface_addresses() (Lin Zhang)
  * test: pass test when hostname is single character (毛毛)
  * ibmi: set the highest process priority to -10 (Xu Meng)
  * build: remove support for gyp (Ben Noordhuis)
  * doc: add note to README on cross-compiling (Ben Noordhuis)
  * fs: add uv_fs_lutime() (Sk Sajidul Kadir)
  * unix: implement cpu_relax() for arm (David Carlier)
  * linux: fix uv__accept4() (twosee)
  * win: handle file paths in uv_fs_statfs() (erw7)
  * unix: fix uv_os_environ() null pointer check (Rikard Falkeborn)
  * win: fix uv_os_environ() null pointer check (Rikard Falkeborn)
  * unix: fix compilation on macOS 32-bit architectures (Brad King)
  * win: replace alloca() with stack-based array (Ben Noordhuis)
* Mon Feb 24 2020 Tomáš Chvátal <tchvatal@suse.com>
- Add baselibs.conf to generate 32bit lib needed for bind
* Tue Feb  4 2020 Martin Liška <mliska@suse.cz>
- Update to libuv 1.34.2:
  * Remove fno-common-build-errs.patch and rebase
    fix_tests.patch.
  Changes since version 1.34.1:
  * misc: adjust stalebot deadlines (Jameson Nash)
  * test: fix env-vars flakiness (cjihrig)
  * test: avoid truncating output lines (Jameson Nash)
  * darwin: stop calling SetApplicationIsDaemon() (Ben Noordhuis)
  * ibmi: implement uv_interface_addresses() (Xu Meng)
  * osx,fsevent: fix race during uv_loop_close (Jameson Nash)
  * osx,fsevent: clear pointer when deleting it [NFCI] (Jameson Nash)
  * Revert "aix: replace ECONNRESET with EOF if already closed" (Jameson Nash)
  * unix: handle uv__open_cloexec return value correctly (Anna Henningsen)
  Changes since version 1.34.0:
  * unix: fix -Wstrict-aliasing compiler warning (Ben Noordhuis)
  * unix: cache address of dlsym("mkostemp") (Ben Noordhuis)
  * build: remove -pedantic from compiler flags (Ben Noordhuis)
  * Revert "darwin: assume pthread_setname_np() is available" (Ben Noordhuis)
  * Revert "darwin: speed up uv_set_process_title()" (Ben Noordhuis)
  * darwin: assume pthread_setname_np() is available (Ben Noordhuis)
  * ibmi: fix the false isatty() issue on IBMi (Xu Meng)
  * test: fix test failure under NetBSD and OpenBSD (David Carlier)
  * test: skip some test cases on IBMi (Xu Meng)
  * test: skip uv_(get|set)_process_title on IBMi (Xu Meng)
  * doc: remove binaries for Windows from README (Richard Lau)
  * unix: fix -Wunused-but-set-variable warning (George Zhao)
  * unix: pass sysctl size arg using ARRAY_SIZE macro (David Carlier)
  * test: disallow running the test suite as root (cjihrig)
  * unix: suppress -Waddress-of-packed-member warning (Ben Noordhuis)
  * misc: make more tags "not-stale" (Jameson Nash)
  * test: fix pthread memory leak (Trevor Norris)
  * docs: delete socks5-proxy sample (Jameson Nash)
  * ibmi: fix the CMSG length issue (Xu Meng)
  * docs: fix formatting (Jameson Nash)
  * unix: squelch fchmod() EPERM on CIFS share (Ben Noordhuis)
  * docs: fix linkcheck (Jameson Nash)
  * docs: switch from linux.die.net to man7.org (Jameson Nash)
  * win: remove abort when non-IFS LSP detection fails (virtualyw)
  * docs: clarify that uv_pipe_t is a pipe (Jameson Nash)
  * win,tty: avoid regressions in utf-8 handling (Jameson Nash)
  * win: remove bad assert in uv_loop_close (Jameson Nash)
  * test: fix -fno-common build errors (Ben Noordhuis)
  * build: turn on -fno-common to catch regressions (Ben Noordhuis)
  * test: fix fs birth time test failure (Ben Noordhuis)
  * tty,unix: avoid affecting controlling TTY (Jameson Nash)
  Changes since version 1.33.1:
  * unix: move random-sysctl to random-sysctl-linux (nia)
  * netbsd: use KERN_ARND sysctl to get entropy (nia)
  * unix: refactor uv__fs_copyfile() logic (cjihrig)
  * build: fix android build, add missing sources (Ben Noordhuis)
  * build: fix android build, fix symbol redefinition (Ben Noordhuis)
  * build: fix android autotools build (Ben Noordhuis)
  * fs: handle non-functional statx system call (Milad Farazmand)
  * unix,win: add uv_sleep() (cjihrig)
  * doc: add richardlau to maintainers (Richard Lau)
  * aix: fix netmask for IPv6 (Richard Lau)
  * aix: clean up after errors in uv_interface_addresses() (Richard Lau)
  * aix: fix setting of physical addresses (Richard Lau)
  * fs: add uv_fs_mkstemp (Saúl Ibarra Corretgé)
  * unix: switch uv_sleep() to nanosleep() (Ben Noordhuis)
  * unix: retry on EINTR in uv_sleep() (Ben Noordhuis)
  * zos: fix nanosleep() emulation (Ben Noordhuis)
  Changes since version 1.33.0:
  * linux: fix arm64 SYS__sysctl build breakage (Ben Noordhuis)
  Changes since version 1.32.0:
  * Revert "linux: drop code path for epoll_pwait-less kernels" (Yang Yu)
  * build: fix build error with __ANDROID_API__ < 21 (Yang Yu)
  * win: fix reading hidden env vars (Anna Henningsen)
  * unix,win: add uv_random() (Ben Noordhuis)
  * win: simplify mkdtemp (Saúl Ibarra Corretgé)
  * docs: fix literal-includes in User Guide (Nhan Khong)
  * win, tty: fix problem of receiving unexpected SIGWINCH (erw7)
  * unix: fix {Net,Open}BSD build (David Carlier)
  * win,mingw: Fix undefined MCAST_* constants (Crunkle)
  * build: Add link for test/fixtures/lorem_ipsum.txt (Andrew Paprocki)
  * fs: use statvfs in uv__fs_statfs() for Haiku (Calvin Hill)
  * fsevents: stop using fsevents to watch files (Jameson Nash)
  * fsevents: regression in watching / (Jameson Nash)
  * build,cmake: don't try to detect a C++ compiler (Isabella Muerte)
  * build: fix build warning on cygwin (MaYuming)
  * unix: set sin_len and sin6_len (Ouyang Yadong)
  * test: fix order of operations in test (cjihrig)
  * doc: improve uv_fs_readdir() cleanup docs (cjihrig)
  * build: remove duplicated test in build files (ZYSzys)
  * android: enable getentropy on Android >= 28 (David Carlier)
  * android: fix build (David Carlier)
  * darwin: speed up uv_set_process_title() (Ben Noordhuis)
  * darwin: assume pthread_setname_np() is available (Ben Noordhuis)
  * unix,udp: ensure addr is non-null (Jameson Nash)
  * win,tty: add uv_tty_{get,set}_vterm_state (erw7)
  * win: fix uv_statfs_t leak in uv_fs_statfs() (Ryan Liptak)
  * build: install files on windows via cmake (Carl Lei)
  * darwin,test: include AvailabilityMacros.h (Saúl Ibarra Corretgé)
  * darwin,test: update loop time after sleeping (Saúl Ibarra Corretgé)
  * doc: remove old FreeBSD 9 related note (Saúl Ibarra Corretgé)
  * doc: improve uv_{send,recv}_buffer_size() docs (Ryan Liptak)
  * build: move -Wno-long-long check to configure time (Ben Noordhuis)
  * unix: update uv_fs_copyfile() fallback logic (Stefan Bender)
  * win: cast setsockopt struct to const char* (Shelley Vohr)
  Changes since version 1.31.0:
  * misc: enable stalebot (Saúl Ibarra Corretgé)
  * win: map ERROR_ENVVAR_NOT_FOUND to UV_ENOENT (cjihrig)
  * win: use L'\0' as UTF-16 null terminator (cjihrig)
  * win: support retrieving empty env variables (cjihrig)
  * unix,stream: fix returned error codes (Santiago Gimeno)
  * test: fix typo in DYLD_LIBRARY_PATH (Ben Noordhuis)
  * unix,signal: keep handle active if pending signal (Santiago Gimeno)
  * openbsd: fix uv_cpu_info (Santiago Gimeno)
  * src: move uv_free_cpu_info to uv-common.c (Santiago Gimeno)
  * tcp: add uv_tcp_close_reset method (Santiago Gimeno)
  * test: fix udp-multicast-join tests (Santiago Gimeno)
  * test: remove assertion in fs_statfs test (cjihrig)
  * doc: clarify uv_buf_t usage in uv_alloc_cb (Tomas Krizek)
  * win: fix typo in preprocessor expression (Konstantin Podsvirov)
  * timer: fix uv_timer_start on closing timer (seny)
  * udp: add source-specific multicast support (Vladimir Karnushin)
  * udp: fix error return values (Santiago Gimeno)
  * udp: drop IPV6_SSM_SUPPORT macro (Santiago Gimeno)
  * udp: fix uv__udp_set_source_membership6 (Santiago Gimeno)
  * udp: use sockaddr_storage instead of union (Santiago Gimeno)
  * build,zos: add _OPEN_SYS_SOCK_EXT3 flag (Santiago Gimeno)
  * test: add specific source multicast tests (Santiago Gimeno)
  * include: map EILSEQ error code (cjihrig)
  * win, tty: improve SIGWINCH performance (Bartosz Sosnowski)
  * build: fix ios build error (MaYuming)
  * aix: replace ECONNRESET with EOF if already closed (Milad Farazmand)
  * build: add cmake library VERSION, SOVERSION (Eneas U de Queiroz)
  * build: make include/ public in CMakeLists.txt (Ben Noordhuis)
  * build: export USING_UV_SHARED=1 to cmake deps (Ben Noordhuis)
  * build: cmake_minimum_required(VERSION 2.8.12) (Daniel Hahler)
  * aix: Fix broken cmpxchgi() XL C++ specialization. (Andrew Paprocki)
  * test: fix -Wsign-compare warning (Ben Noordhuis)
  * unix: simplify open(O_CLOEXEC) feature detection (Ben Noordhuis)
  * unix: fix UV_FS_O_DIRECT definition on Linux (Joran Dirk Greef)
  * doc: uv_handle_t documentation suggestion (Daniel Bevenius)
* Wed Jan  8 2020 Matej Cepl <mcepl@suse.com>
- Add fno-common-build-errs.patch which fixes gh#libuv/libuv#2603
  (bsc#1160280)
* Sun Sep  1 2019 Andreas Stieger <andreas.stieger@gmx.de>
- libuv 1.31.0:
  * unix,win: add uv_fs_statfs()
  * test: avoid AF_LOCAL
  * add ability to retrieve all env variables
  * doc: add %%p to valgrind log-file arg
  * doc: fix typo in basics.rst
  * unix: clear UV_HANDLE_READING flag before callback
- add project signing keyring and verify source signature
* Wed Jul  3 2019 Matej Cepl <mcepl@suse.com>
- Upgrade to 1.30.1:
  * doc: fix incorrect versionchanged (cjihrig)
  * test: allow UV_ECONNRESET in tcp_try_write_error (cjihrig)
  * unix: add uv_get_constrained_memory() cygwin stub (cjihrig)
  * build: fix android cmake build (Ben Noordhuis)
  * unix: squelch -Wcast-function-type warning (Ben Noordhuis)
  * build: fix compile error with uClibc (zlargon)* darwin: fall
    back to F_BARRIERFSYNC (Ben Noordhuis)
  * darwin: add 32 bit close$NOCANCEL implementation
    (ken-cunningham-webuse)
  * build, core, unix: add support for Haiku (Leorize)
  * darwin,linux: more conservative minimum stack size (Ben Noordhuis)
  * threadpool: increase UV_THREADPOOL_SIZE limit (Vlad A)
  * unix: return actual error from `uv_try_write()` (Anna Henningsen)
  * darwin: fix build error with macos 10.10 (Ben Noordhuis)
  * unix: make uv_cwd() report UV_ENOBUFS (Ben Noordhuis)
  * unix: make uv_fs_read() fill all buffers (Ben Noordhuis)
  * test: give hrtime test a custom 10s timeout (Ben Noordhuis)
  * fs: fix uv_fs_copyfile if same src and dst (Santiago Gimeno)
  * build: add cmake option to skip building tests (Niels Lohmann)
  * doc: add link to nodejs.org (Jenil Christo)
  * unix: fix a comment typo in signal.c (Evgeny Ermakov)
  * unix: remove redundant cast in process.c (gengjiawen)
  * doc: fix wrong mutex function prototypes (Leo Chung)
  * unix: simplify uv/posix.h include logic (cjihrig)
  * test: increase test timeout (cjihrig)
  * linux: fix sscanf() overflows reading from /proc (Ben Noordhuis)
  * ibmi: read memory and CPU usage info (Xu Meng)
  * doc: update the cmake testing instruction (zlargon)
  * unix: fix race condition in uv_async_send() (Ben Noordhuis)
  * linux: use O_CLOEXEC instead of EPOLL_CLOEXEC (Ben Noordhuis)
  * doc: mark uv_async_send() as async-signal-safe (Ben Noordhuis)
  * linux: init st_flags and st_gen when using statx (Oscar Waddell)
  * linux: read free/total memory from /proc/meminfo (Ben Noordhuis)
  * test: test zero-sized uv_fs_sendfile() writes (Ben Noordhuis)
  * unix: don't assert on UV_PROCESS_WINDOWS_* flags (Ben Noordhuis)
  * linux: set correct mac address for IP-aliases (Santiago Gimeno)
  * win,util: fix null pointer dereferencing (Tobias Nießen)
  * unix,win: fix `uv_fs_poll_stop()` when active (Anna Henningsen)
  * doc: add missing uv_fs_type entries (Michele Caini)
  * doc: fix build with sphinx 2.x (FX Coudert)
  * unix: don't make statx system call on Android (George Zhao)
  * unix: fix clang scan-build warning (Kyle Edwards)
  * unix: fall back to kqueue on older macOS systems (ken-cunningham-webuse)
  * unix,win: add uv_get_constrained_memory() (Kelvin Jin)
  * darwin: fix thread cancellation fd leak (Ben Noordhuis)
  * linux: fix thread cancellation fd leak (Ben Noordhuis)
  * unix,win: add uv_gettimeofday() (cjihrig)
  * unix,win: add uv_fs_{open,read,close}dir() (cjihrig)
  * unix: fix uv_interface_addresses() (Andreas Rohner)
  * fs: remove macOS-specific copyfile(3) (Rich Trott)
  * fs: add test for copyfile() respecting permissions (Rich Trott)
  * build: partially revert 5234b1c (Ben Noordhuis)
  * zos: fix setsockopt error when using AF_UNIX (Milad Farazmand)
  * unix: suppress EINTR/EINPROGRESS in uv_fs_close() (Ben Noordhuis)
  * build: use cmake APPLE variable to detect platform (zlargon)
  * distcheck: remove duplicate test/ entry (Jameson Nash)
  * unix: remove unused cmpxchgl() function (Ben Noordhuis)
  * unix: support sockaddr_un in uv_udp_send() (Yury Selivanov)
  * unix: guard use of PTHREAD_STACK_MIN (Kamil Rytarowski)
  * unix,win: introduce uv_timeval64_t (cjihrig)
  * doc: document uv_timeval_t and uv_timeval64_t (cjihrig)
* Thu Mar 21 2019 Ondřej Súkup <mimi.vx@gmail.com>
- update to 1.27.0
  * doc: describe unix signal handling better (Vladimír Čunát)
  * linux: use statx() to obtain file birth time (Ben Noordhuis)
  * src: fill sockaddr_in6.sin6_len when it's defined (Santiago Gimeno)
  * test: relax uv_hrtime() test assumptions (Ben Noordhuis)
  * build: make cmake install LICENSE only once (Thomas Karl Pietrowski)
  * bsd: plug uv_fs_event_start() error path fd leak (Ben Noordhuis)
  * doc: add note about uv_run() not being reentrant (Ben Noordhuis)
  * unix, win: make fs-poll close wait for resource cleanup (Anna Henningsen)
  * doc: fix typo in uv_thread_options_t definition (Ryan Liptak)
  * win: skip winsock initialization in safe mode (evgley)
  * unix: refactor getsockname/getpeername methods (Santiago Gimeno)
  * udp: add support for UDP connected sockets (Santiago Gimeno)
  * build: add missing header (cjihrig)
  * test: change spawn_stdin_stdout return to void (Andrew Paprocki)
  * test: remove call to floor() in test driver (Andrew Paprocki)
* Thu Feb 28 2019 Ondřej Súkup <mimi.vx@gmail.com>
- update to version 1.26.0
  * doc: fix uv_get_free_memory doc (Stephen Belanger)
  * unix: fix epoll cpu 100%% issue (yeyuanfeng)
  * openbsd,tcp: special handling of EINVAL on connect (ptlomholt)
  * src,include: define UV_MAXHOSTNAMESIZE (cjihrig)
  * thread: allow specifying stack size for new thread (Anna Henningsen)
  * unix: don't attempt to invalidate invalid fd (Ben Noordhuis)
  * Revert "win,fs: retry if uv_fs_rename fails" (Ben Noordhuis)
  * aix: manually trigger fs event monitoring (Gireesh Punathil)
  * unix: rename WRITE_RETRY_ON_ERROR macro (Ben Noordhuis)
  * unix: refactor uv__write() (Ben Noordhuis)
  * unix: don't send handle twice on partial write (Ben Noordhuis)
  * tty,win: fix Alt+key under WSL (Bartosz Sosnowski)
  * build: support running tests in out-of-tree builds (Jameson Nash)
  * fsevents: really watch files with fsevents on macos 10.7+ (Jameson Nash)
  * thread,mingw64: need intrin.h header for SSE2 MemoryBarrier (Jameson Nash)
  * win: fix sizeof-pointer-div warning (cjihrig)
  * unix,win: add uv_os_uname() (cjihrig)
  * win, tty: fix CreateFileW() return value check (Bartosz Sosnowski)
  * unix: enable IPv6 tests on OpenBSD (ptlomholt)
  * test: fix test-ipc spawn_helper exit_cb (Santiago Gimeno)
  * test: fix test-ipc tests (Santiago Gimeno)
  * unix: better handling of unsupported F_FULLFSYNC (Victor Costan)
  * unix,stream: fix zero byte writes (Santiago Gimeno)
  * ibmi: return EISDIR on read from directory fd (Kevin Adler)
  * build: wrap long lines in Makefile.am (cjihrig)
  test: fix platform_output test on cygwin (damon-kwok)
  * gitignore: ignore build/ directory (Damon Kwok)
  * unix: zero epoll_event before use (Ashe Connor)
  * doc: replace deprecated build command on macOS (Rick)
  * warnings: fix code that emits compiler warnings (Jameson Nash)
  * doc: clarify expected memory management strategy (Ivan Krylov)
  * test: add uv_inet_ntop(AF_INET) coverage (Ben Noordhuis)
  * unix: harden string copying, introduce strscpy() (Ben Noordhuis)
  * linux: get rid of strncpy() call (Ben Noordhuis)
* Thu Nov 22 2018 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.24.0:
  * unix: do not require PATH_MAX to be defined (Brad King)
  * win,doc: path encoding in uv_fs_XX is UTF-8 (hitesh)
  * unix: add missing link dependency on kFreeBSD (Svante Signell)
  * unix: add support for GNU/Hurd (Samuel Thibault)
  * test: avoid memory leak for test_output (Carlo Marcelo Arenas Belón)
  * doc: add vtjnash to maintainers (Jameson Nash)
  * unix: restore skipping of phys_addr copy (cjihrig)
  * unix,win: make uv_interface_addresses() consistent (cjihrig)
  * unix: remove unnecessary linebreaks (cjihrig)
  * unix,win: handle zero-sized allocations uniformly (Ben Noordhuis)
  * unix: remove unused uv__dup() function (Ben Noordhuis)
  * core,bsd: refactor process_title functions (Santiago Gimeno)
  * test: make sure that reading a directory fails (Sakthipriyan Vairamani)
  * win, tty: remove zero-size read callbacks (Bartosz Sosnowski)
  * test: fix test runner getenv async-signal-safety (Ben Noordhuis)
  * test: fix test runner execvp async-signal-safety (Ben Noordhuis)
  * test,unix: fix race in test runner (Ben Noordhuis)
  * unix,win: support IDNA 2008 in uv_getaddrinfo() (Ben Noordhuis)
* Thu Oct 11 2018 adam.majer@suse.de
- Update to version 1.23.2:
  * unix: return 0 retrieving rss on cygwin
  * unix: initialize uv_interface_address_t.phys_addr
  * test: handle uv_os_setpriority() windows edge case
  * tty, win: fix read stop for raw mode
  * Revert "Revert "unix,fs: fix for potential partial reads/writes""
  * unix,readv: always permit partial reads to return
  * win,tty: fix uv_tty_close()
  * doc: remove extraneous "on
  * unix,win: fix threadpool race condition
  * unix: rework thread barrier implementation
  * unix: signal done to last thread barrier waiter
  * unix: optimize uv_fs_readlink() memory allocation
  For complete changelog please see
  https://github.com/libuv/libuv/releases
  * install license as %%license
  * fix_tests.patch: fix unit tests on OBS
  * fix for bsc#1199062 (backported as
  0001-linux-remove-epoll-syscall-wrappers.patch and
  0002-linux-drop-code-path-for-epoll_pwait-less-kernels.patch) is
  included in upstream releases from 1.23.1 on
* Sun Dec 24 2017 avindra@opensuse.org
- Update to version 1.18.0
  * unix,win: add uv_os_getpid()
  * unix: remove incorrect assertion in uv_shutdown()
  * aix: fix -Wmaybe-uninitialized warning
  * win,doc: remove note about SIGWINCH on Windows
  * doc: fix IRC URL in CONTRIBUTING.md
- 1.17.0
  * ibmi: add support for new platform
  * unix: keep track of bound sockets sent via spawn
  * unix: avoid malloc() call in uv_spawn()
  * zos: add strnlen() implementation
  * test: add threadpool init/teardown test
  * test: avoid malloc() in threadpool test
  * test: lower number of tasks in threadpool test
  * test: fix test-spawn compilation
  * doc: clarify the description of uv_loop_alive()
  * win: issue memory barrier in uv_thread_join()
  * win: map UV_FS_O_EXLOCK to a share mode of 0
  * win: fix build on case-sensitive file systems
  * win: fix test runner build with mingw64
  * win: remove unused variable in test/test-fs.c
- 1.16.1
  * unix: move net/if.h include
  * win: fix undeclared NDIS_IF_MAX_STRING_SIZE
- 1.16.0
  * unix,win: add fs open flags, map O_DIRECT|O_DSYNC
  * win, fs: fix non-symlink reparse points
  * test: fix -Wstrict-prototypes warnings
  * unix, windows: map ENOTTY errno
  * unix: fall back to fsync() if F_FULLFSYNC fails
  * unix: do not close invalid kqueue fd after fork
  * zos: reset epoll data after fork
  * zos: skip fork_threadpool_queue_work_simple
  * test: keep platform_output as first test
  * unix,win: add uv_os_getppid()
  * test: fix const qualification compiler warning
  * doc: mark uv_default_loop() as not thread safe
  * win, pipe: null-initialize stream->shutdown_req
  * tty, win: get SetWinEventHook pointer at startup
  * test: no extra new line in skipped test output
  * pipe: allow access from other users
  * unix,win: add uv_if_{indextoname,indextoiid}
  * win: fix non-English dlopen error message
  * win: change st_blksize from `2048` to `4096`
- Small spec file cleanup
* Wed Nov  1 2017 mpluskal@suse.com
- Do not use source URL as fetching fails over ipv6
* Thu Oct 19 2017 mpluskal@suse.com
- Update to version 1.15.0:
  * win: fix buffer size in uv__getpwuid_r()
  * unix: use fchmod() in uv_fs_copyfile()
  * unix: support copying empty files
  * unix: truncate destination in uv_fs_copyfile()
  * linux: increase thread stack size with musl libc
  * test: clean up semaphore after use
  * unix: check for NULL in uv_os_unsetenv for parameter name
  * For extensive list of changes since last release see provided
    ChangeLog
- Small spec file cleanup
* Wed Nov 23 2016 qantas94heavy@gmail.com
- Update to 1.10.1
  * win: fix anonymous union syntax
  * unix: use uv__is_closing everywhere
  * win: add missing break statement
  * doc: fix wrong man page link for uv_fs_lstat()
  * win, tty: handle empty buffer in uv_tty_write_bufs
  * doc: add cjihrig alternative GPG ID
  * Revert "win,tty: add support for ANSI codes in win10 v1511"
- Add signature and keyring for GPG source verification
* Sun Nov 13 2016 aloisio@gmx.com
- Update to 1.10.0
* Wed Jul 27 2016 jengelh@inai.de
- Trim filler words from description
* Sat Jan 30 2016 mpluskal@suse.com
- Update to 1.8.0
  * unix: fix memory leak in uv_interface_addresses (Jianghua Yang)
  * unix: make uv_guess_handle work properly for AIX (Gireesh
    Punathil)
  * fs: undo uv__req_init when uv__malloc failed (Jianghua Yang)
  * build: remove unused 'component' GYP option (Saúl Ibarra
    Corretgé)
  * include: remove duplicate extern declaration (Jianghua Yang)
  * win: use the MSVC provided snprintf where possible (Jason
    Williams)
  * win, test: fix compilation warning (Saúl Ibarra Corretgé)
  * win: fix compilation with VS < 2012 (Ryan Johnston)
  * stream: support empty uv_try_write on unix (Fedor Indutny)
  * unix: fix request handle leak in uv__udp_send (Jianghua Yang)
  * src: replace QUEUE_SPLIT with QUEUE_MOVE (Ben Noordhuis)
  * unix: use QUEUE_MOVE when iterating over lists (Ben Noordhuis)
  * unix: squelch harmless valgrind warning (Ben Noordhuis)
  * test: don't abort on setrlimit() failure (Ben Noordhuis)
  * unix: only undo fs req registration in async mode (Ben
    Noordhuis)
  * unix: fix uv__getiovmax return value (HungMingWu)
  * unix: make work with Solaris Studio. (Adam Stylinski)
  * test: fix fs_event_watch_file_currentdir flakiness (Santiago
    Gimeno)
  * unix: skip prohibited syscalls on tvOS and watchOS (Nathan
    Corvino)
  * test: use FQDN in getaddrinfo_fail test (Wink Saville)
  * docs: clarify documentation of uv_tcp_init_ex (Andrius
    Bentkus)
  * win: fix comment (Miodrag Milanovic)
  * doc: fix typo in README (Angel Leon)
  * darwin: abort() if (un)locking fs mutex fails (Ben Noordhuis)
  * pipe: enable inprocess uv_write2 on Windows (Louis DeJardin)
  * win: properly return UV_EBADF when _close() fails (Nicholas
    Vavilov)
  * test: skip process_title for AIX (Imran Iqbal)
  * misc: expose handle print APIs (Petka Antonov)
  * include: add stdio.h to uv.h (Saúl Ibarra Corretgé)
  * misc: remove unnecessary null pointer checks (Ian Kronquist)
  * test,freebsd: skip udp_dual_stack if not supported (Santiago
    Gimeno)
  * linux: don't retry dup2/dup3 on EINTR (Ben Noordhuis)
  * unix: don't retry dup2/dup3 on EINTR (Ben Noordhuis)
  * test: fix -Wtautological-pointer-compare warnings (Saúl Ibarra
    Corretgé)
  * win: map ERROR_BAD_PATHNAME to UV_ENOENT (Tony Kelman)
  * test: fix test/test-tty.c for AIX (Imran Iqbal)
  * android: support api level less than 21 (kkdaemon)
  * fsevents: fix race on simultaneous init+close (Fedor Indutny)
  * linux,fs: fix p{read,write}v with a 64bit offset (Saúl Ibarra
    Corretgé)
  * fs: add uv_fs_realpath() (Yuval Brik)
  * win: fix path for removed and renamed fs events (Joran Dirk
    Greef)
  * win: do not read more from stream than available (Jeremy
    Whitlock)
  * test: test that uv_close() doesn't corrupt QUEUE (Andrey Mazo)
  * unix: fix uv_fs_event_stop() from fs_event_cb (Andrey Mazo)
  * test: fix self-deadlocks in thread_rwlock_trylock (Ben
    Noordhuis)
  * src: remove non ascii character (sztomi)
  * test: fix test udp_multicast_join6 for AIX (Imran Iqbal)
* Sun Dec  6 2015 mpluskal@suse.com
- Make building more verbose
* Sat Oct  3 2015 mrueckert@suse.de
- Update to 1.7.5
  - unix: Support atomic compare & swap xlC on AIX (nmushell)
  - unix: Fix including uv-aix.h on AIX (nmushell)
  - unix: consolidate rwlock tryrdlock trywrlock errors (Saúl
    Ibarra Corretgé)
  - unix, win: consolidate mutex trylock errors (Saúl Ibarra
    Corretgé)
  - darwin: fix memory leak in uv_cpu_info (Jianghua Yang)
  - test: add tests for the uv_rwlock implementation (Bert Belder)
  - win: redo/fix the uv_rwlock APIs (Bert Belder)
  - win: don't fetch function pointers to SRWLock APIs (Bert
    Belder)
- Changes for 1.7.4:
  - doc: uv_read_start and uv_read_cb clarifications (Ben Trask)
  - freebsd: obtain true uptime through clock_gettime() (Jianghua
    Yang)
  - win, tty: do not convert \r to \r\n (Colin Snover)
  - build,gyp: add DragonFly to the list of OSes (Michael Neumann)
  - fs: fix bug in sendfile for DragonFly (Michael Neumann)
  - doc: add uv_dlsym() return type (Brian White)
  - tests: fix fs tests run w/o full getdents support (Jeremy
    Whitlock)
  - doc: fix typo (Devchandra Meetei Leishangthem)
  - doc: fix uv-unix.h location (Sakthipriyan Vairamani)
  - unix: fix error check when closing process pipe fd (Ben
    Noordhuis)
  - test,freebsd: fix ipc_listen_xx_write tests (Santiago Gimeno)
  - win: fix unsavory rwlock fallback implementation (Bert Belder)
  - doc: clarify repeat timer behavior (Eli Skeggs)
- Changes for 1.7.3:
  - threadpool: fix thread starvation bug (Ben Noordhuis)
- Changes for 1.7.2:
  - unix, win: make uv_loop_init return on error (Willem Thiart)
  - win: reset pipe handle for pipe servers (Saúl Ibarra Corretgé)
  - win: fix replacing pipe handle for pipe servers (Saúl Ibarra
    Corretgé)
  - win: fix setting pipe pending instances after bind (Saúl Ibarra
    Corretgé)
- Changes for 1.7.1:
  - doc: document the procedure for verifying releases (Saúl Ibarra
    Corretgé)
  - doc: add note about Windows binaries to the README (Saúl Ibarra
    Corretgé)
  - doc: use long GPG IDs in MAINTAINERS.md (Saúl Ibarra Corretgé)
  - Revert "stream: squelch ECONNRESET error if already closed"
    (Saúl Ibarra Corretgé)
  - doc: clarify uv_read_stop() is idempotent (Corbin Simpson)
  - unix: OpenBSD's setsockopt needs an unsigned char for multicast
    (Zachary Hamm)
  - test: Fix two memory leaks (Karl Skomski)
  - unix,win: return EINVAL on nullptr args in uv_fs_{read,write}
    (Karl Skomski)
  - win: set accepted TCP sockets as non-inheritable (Saúl Ibarra
    Corretgé)
  - unix: remove superfluous parentheses in fs macros (Ben
    Noordhuis)
  - unix: don't copy arguments for sync fs requests (Ben Noordhuis)
  - test: plug small memory leak in unix test runner (Ben
    Noordhuis)
  - unix,windows: allow NULL loop for sync fs requests (Ben
    Noordhuis)
  - unix,windows: don't assert on unknown error code (Ben
    Noordhuis)
  - stream: retry write on EPROTOTYPE on OSX (Brian White)
  - common: fix use of snprintf on Windows (Saúl Ibarra Corretgé)
  - tests: refactored fs watch_dir tests for stability (Jeremy
    Whitlock)
- Changes for 1.7.0:
  - win,stream: add slot to remember CRT fd (Bert Belder)
  - win,pipe: properly close when created from CRT fd (Bert Belder)
  - win,pipe: don't close fd 0-2 (Bert Belder)
  - win,tty: convert fd -> handle safely (Bert Belder)
  - win,tty: properly close when created from CRT fd (Bert Belder)
  - win,tty: don't close fd 0-2 (Bert Belder)
  - win,fs: don't close fd 0-2 (Bert Belder)
  - win: include "malloc.h" (Cheng Zhao)
  - windows: MSVC 2015 has C99 inline (Jason Williams)
  - dragonflybsd: fixes for nonblocking and cloexec (Michael
    Neumann)
  - dragonflybsd: use sendfile(2) for uv_fs_sendfile (Michael
    Neumann)
  - dragonflybsd: fix uv_exepath (Michael Neumann)
  - win,fs: Fixes align(8) directive on mingw (Stefano Cristiano)
  - unix, win: prevent replacing fd in uv_{udp,tcp,pipe}_t (Saúl
    Ibarra Corretgé)
  - win: move logic to set socket non-inheritable to
    uv_tcp_set_socket (Saúl Ibarra Corretgé)
  - unix, win: add ability to create tcp/udp sockets early (Saúl
    Ibarra Corretgé)
  - test: retry select() on EINTR, honor milliseconds (Ben
    Noordhuis)
  - unix: consolidate tcp and udp bind error (Saúl Ibarra Corretgé)
  - test: conditionally skip udp_ipv6_multicast_join6 (heshamsafi)
  - core: add UV_VERSION_HEX macro (Saúl Ibarra Corretgé)
  - doc: add section with version-checking macros and functions
    (Saúl Ibarra Corretgé)
  - tty: cleanup handle if uv_tty_init fails (Saúl Ibarra Corretgé)
  - darwin: save a fd when FSEvents is used (Saúl Ibarra Corretgé)
  - win: fix returning thread id in uv_thread_self (Saúl Ibarra
    Corretgé)
  - common: use offsetof for QUEUE_DATA (Saúl Ibarra Corretgé)
  - win: remove UV_HANDLE_CONNECTED (A. Hauptmann)
  - docs: add Windows specific note for uv_fs_open (Saúl Ibarra
    Corretgé)
  - doc: add note about uv_fs_scandir (Saúl Ibarra Corretgé)
  - test,unix: reduce stack size of watchdog threads (Ben
    Noordhuis)
  - win: add support for recursive file watching (Saúl Ibarra
    Corretgé)
  - win,tty: support consoles with non-default colors (John
    McNamee)
  - doc: add missing variable name (Yosuke Furukawa)
  - stream: squelch ECONNRESET error if already closed (Santiago
    Gimeno)
  - build: remove ancient condition from common.gypi (Saúl Ibarra
    Corretgé)
  - tests: skip some tests when network is unreachable (Luca Bruno)
  - build: proper support for android cross compilation (guworks)
  - android: add missing include to pthread-fixes.c (RossBencina)
  - test: fix compilation warning (Saúl Ibarra Corretgé)
  - doc: add a note about uv_dirent_t.type (Saúl Ibarra Corretgé)
  - win,test: fix shared library build (Saúl Ibarra Corretgé)
  - test: fix compilation warning (Santiago Gimeno)
  - build: add experimental Windows installer (Roger A. Light)
  - threadpool: send signal only when queue is empty (chenttuuvv)
  - aix: fix uv_exepath with relative paths (Richard Lau)
  - build: fix version syntax in AppVeyor file (Saúl Ibarra
    Corretgé)
  - unix: allow nbufs > IOV_MAX in uv_fs_{read,write} (ronkorving)
* Wed Aug  5 2015 mpluskal@suse.com
- Update to 1.6.1
  * unix: handle invalid _SC_GETPW_R_SIZE_MAX values (cjihrig)
- Changes for 1.6.0
  * aix: fix setsockopt for multicast options (Michael)
  * unix: don't block for io if any io handle is primed (Saúl
    Ibarra Corretgé)
  * windows: MSVC 2015 has snprintf() (Rui Abreu Ferreira)
  * windows: Add VS2015 support to vcbuild.bat (Jason Williams)
  * doc: fix typo in tcp.rst (Igor Soarez)
  * linux: work around epoll bug in kernels < 2.6.37 (Ben
    Noordhuis)
  * unix,win: add uv_os_homedir() (cjihrig)
  * stream: fix `select()` race condition (Fedor Indutny)
  * unix: prevent infinite loop in uv__run_pending (Saúl Ibarra
    Corretgé)
  * unix: make sure UDP send callbacks are asynchronous (Saúl
    Ibarra Corretgé)
  * test: fix `platform_output` netmask printing. (Andrew Paprocki)
  * aix: add ahafs autoconf detection and README notes (Andrew
    Paprocki)
  * core: add ability to customize memory allocator (Saúl Ibarra
    Corretgé)
- Changes for 1.5.0
  * doc: clarify that the thread pool primites are not thread safe
    (Andrius Bentkus)
  * aix: always deregister closing fds from epoll (Michael)
  * unix: fix glibc-2.20+ macro incompatibility (Massimiliano
    Torromeo)
  * doc: add Sphinx plugin for generating links to man pages
    (Saúl Ibarra Corretgé)
  * doc: link system and library calls to man pages (Saúl
    Ibarra Corretgé)
  * doc: document uv_getnameinfo_t.{host|service} (Saúl Ibarra
    Corretgé)
  * build: update the location of gyp (Stephen von Takach)
  * win: name all anonymous structs and unions (TomCrypto)
  * linux: work around epoll bug in kernels 3.10-3.19 (Ben
    Noordhuis)
  * darwin: fix size calculation in select() fallback (Ole
    André Vadla Ravnås)
  * solaris: fix setsockopt for multicast options (Julien
    Gilli)
  * test: fix race condition in multithreaded test (Ben Noordhuis)
  * doc: fix long lines in tty.rst (Ben Noordhuis)
  * test: use UV_TTY_MODE_* values in tty test (Ben Noordhuis)
  * unix: don't clobber errno in uv_tty_reset_mode() (Ben
    Noordhuis)
  * unix: reject non-tty fds in uv_tty_init() (Ben Noordhuis)
  * win: fix pipe blocking writes (Alexis Campailla)
  * build: fix cross-compiling for iOS (Steven Kabbes)
  * win: remove unnecessary malloc.h
  * include: use `extern "c++"` for defining C++ code (Kazuho Oku)
  * unix: reap child on execvp() failure (Ryan Phillips)
  * windows: fix handle leak on EMFILE (Brian Green)
  * test: fix tty_file, close handle if initialized (Saúl Ibarra
    Corretgé)
  * doc: clarify what uv_*_open accepts (Saúl Ibarra Corretgé)
  * doc: clarify that we don't maintain external doc resources
    (Saúl Ibarra Corretgé)
  * build: add documentation for ninja support (Devchandra
    Meetei Leishangthem)
  * doc: document uv_buf_t members (Corey Farrell)
  * linux: fix epoll_pwait() fallback on arm64 (Ben Noordhuis)
  * android: fix compilation warning (Saúl Ibarra Corretgé)
  * unix: don't close the fds we just setup (Sam Roberts)
  * test: spawn child replacing std{out,err} to stderr
  * unix: fix swapping fds order in uv_spawn
  * unix: fix potential bug if dup2 fails in uv_spawn
  * test: remove LOG and LOGF variadic macros
  * win: fix uv_fs_access on directories
  * win: fix of double free in uv_uptime
  * unix: open "/dev/null" instead of "/" for emfile_fd
  * docs: add some missing words
  * unix: clean up uv_fs_open() O_CLOEXEC logic
  * build: set SONAME for shared library in uv.gyp
  * windows: define snprintf replacement as inline instead of static
  * win: fix unlink of readonly files
  * doc: fix uv_run(UV_RUN_DEFAULT) description
  * linux: intercept syscall when running under memory sanitizer
  * aix: fix uv_interface_addresses return value
  * windows: defer reporting TCP write failure until next tick
  * test: add test for deferred TCP write failure
* Mon Mar  2 2015 tchvatal@suse.com
- Version bump to 1.4.2:
  * stream: ignore EINVAL for SO_OOBINLINE on OS X (Fedor Indutny)
  * win: don't use inline keyword in thread.c (Ben Noordhuis)  * windows: fix
  * setting dirent types on uv_fs_scandir_next (Saúl Ibarra Corretgé)  *
  * unix,windows: make uv_thread_create() return errno (Ben Noordhuis)  * tty:
  * fix build for SmartOS (Julien Gilli)  * unix: fix for uv_async data race
  * (Michael Penick)  * unix, windows: map EHOSTDOWN errno (Ben Noordhuis)  *
  * stream: use SO_OOBINLINE on OS X (Fedor Indutny)
* Thu Feb 12 2015 tchvatal@suse.com
- Version bump to 1.4.0 which is the latest release
- Cleanup with the spec cleaner
- Try to enable tests and they currently fail
* Mon Sep 15 2014 00:00:00 UTC - daxim@cpan.org
- update to v0.11.29
* Mon Aug 11 2014 00:00:00 UTC - daxim@cpan.org
- update to v0.11.28
* Wed Apr 30 2014 00:00:00 UTC - dmacvicar@suse.de
- update to 0.11.24
- install pkg-config file
* Sun Apr 13 2014 dmitry_r@opensuse.org
- Update to version 0.11.23
  * bug fixes
* Mon Mar 10 2014 daxim@cpan.org
- update to v0.11.21
* Fri Jan 31 2014 daxim@cpan.org
- initial packaging of v0.11.19
